==> python-semantic-release-8.0.0a5.tar.gz: python-semantic-release-8.0.0a5/semantic_release/commit_parser/_base.py <==
from __future__ import annotations

from abc import ABC, abstractmethod
from typing import Any, Generic, TypeVar

from git.objects.commit import Commit

from semantic_release.commit_parser.token import ParseResultType


class ParserOptions:
    """
    ParserOptions should accept the keyword arguments they are interested in
    from configuration and process them as desired, ultimately creating attributes
    on an instance which can be accessed by the corresponding commit parser. For example,
    >>> class MyParserOptions(ParserOptions):
    ...     def __init__(self, message_prefix: str) -> None:
    ...         self.prefix = message_prefix * 2

    >>> class MyCommitParser(AbstractCommitParser):
    ...     parser_options = MyParserOptions
    ...     def parse(self, Commit):
    ...         print(self.options.prefix)
    ...         ...

    Any defaults that need to be set should also be done in this class too.
    Invalid options should be signalled by raising an ``InvalidOptionsException``
    within the ``__init__`` method of the options class.

    A dataclass is also well suited to this; if type-checking of input is desired,
    a ``pydantic.dataclasses.dataclass`` works well and is used internally
    by python-semantic-release. Parser options are not validated in the configuration
    and passed directly to the appropriate class to handle.
    """

    def __init__(self, **_: Any) -> None:
        pass


# TT = TokenType, a subclass of ParsedCommit
_TT = TypeVar("_TT", bound=ParseResultType)
_OPTS = TypeVar("_OPTS", bound=ParserOptions)


class CommitParser(ABC, Generic[_TT, _OPTS]):
    """
    Abstract base class for all commit parsers. Custom commit parsers should inherit
    from this class.

    A class-level ``parser_options`` attribute should be set to a subclass of
    ``BaseParserOptions``; this will be used to provide the default options to the
    parser. Note that a nested class can be used directly, if preferred:

    >>> class MyParser(CommitParser):
            @dataclass
            class parser_options(ParserOptions):
                allowed_types: Tuple[str] = ("feat", "fix", "docs")
                major_types: Tuple[str] = ("breaking",)
                minor_types: Tuple[str] = ("fix", "patch")
                ...
            def __init__(self, options: parser_options) -> None:
                ...
    """

    parser_options: type[_OPTS]

    def __init__(self, options: _OPTS) -> None:
        self.options = options

    @abstractmethod
    def parse(self, commit: Commit) -> _TT:
        ...

==> python-semantic-release-9.2.0.tar.gz: python-semantic-release-9.2.0/semantic_release/commit_parser/_base.py <==
from __future__ import annotations

from abc import ABC, abstractmethod
from typing import TYPE_CHECKING, Any, Generic, TypeVar

from semantic_release.commit_parser.token import ParseResultType

if TYPE_CHECKING:
    from git.objects.commit import Commit


class ParserOptions(dict):
    """
    ParserOptions should accept the keyword arguments they are interested in
    from configuration and process them as desired, ultimately creating attributes
    on an instance which can be accessed by the corresponding commit parser.

    For example:
    >>> class MyParserOptions(ParserOptions):
    ...     def __init__(self, message_prefix: str) -> None:
    ...         self.prefix = message_prefix * 2

    >>> class MyCommitParser(AbstractCommitParser):
    ...     parser_options = MyParserOptions
    ...     def parse(self, Commit):
    ...         print(self.options.prefix)
    ...         ...

    Any defaults that need to be set should also be done in this class too.
    Invalid options should be signalled by raising an ``InvalidOptionsException``
    within the ``__init__`` method of the options class.

    A dataclass is also well suited to this; if type-checking of input is desired,
    a ``pydantic.dataclasses.dataclass`` works well and is used internally
    by python-semantic-release. Parser options are not validated in the configuration
    and passed directly to the appropriate class to handle.
    """

    def __init__(self, **_: Any) -> None:
        pass


# TT = TokenType, a subclass of ParsedCommit
_TT = TypeVar("_TT", bound=ParseResultType)
_OPTS = TypeVar("_OPTS", bound=ParserOptions)


class CommitParser(ABC, Generic[_TT, _OPTS]):
    """
    Abstract base class for all commit parsers. Custom commit parsers should inherit
    from this class.

    A class-level ``parser_options`` attribute should be set to a subclass of
    ``BaseParserOptions``; this will be used to provide the default options to the
    parser. Note that a nested class can be used directly, if preferred:

    >>> class MyParser(CommitParser):
            @dataclass
            class parser_options(ParserOptions):
                allowed_types: Tuple[str] = ("feat", "fix", "docs")
                major_types: Tuple[str] = ("breaking",)
                minor_types: Tuple[str] = ("fix", "patch")
                ...
            def __init__(self, options: parser_options) -> None:
                ...
    """

    parser_options: type[_OPTS]

    def __init__(self, options: _OPTS) -> None:
        self.options = options

    @abstractmethod
    def parse(self, commit: Commit) -> _TT:
        ...
